/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is confidential property of Nordic 
 * Semiconductor ASA.Terms and conditions of usage are described in detail 
 * in NORDIC SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT. 
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRENTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *              
 * $LastChangedRevision: 133 $
 */

/** @file
 * USB descriptor for Bootloader
 *
 */
#include "config.h"

// Place all code and constants in this file in the segment "BOOTLOADER":
#pragma userclass (code = BOOTLOADER)
#pragma userclass (const = BOOTLOADER)

/** Swaps the upper byte with the lower byte in a 16 bit variable */
#define SWAP(x) ((((x)&0xFF)<<8)|(((x)>>8)&0xFF))

#include "usb_desc_bootloader.h"


code usb_dev_desc_t g_usb_dev_desc = {
  sizeof(usb_dev_desc_t), 
  USB_DESC_DEVICE, 
  SWAP(0x0200),       // bcdUSB
  0xff,               // bDeviceClass
  0xff,               // bDeviceSubclass
  0xff,               // bDeviceProtocol
  MAX_PACKET_SIZE_EP0,// bMaxPAcketSize0
  SWAP(6421),         // idVendor - 6421 (0x1915) : Nordic Semiconductor ASA
  SWAP(0x0103),       // idProduct
  SWAP(0x0001),       // bcdDevice - Device Release Number (BCD)
  0x01,               // iManufacturer
  0x02,               // iProduct
  0x00,               // iSerialNumber
  0x01                // bNumConfigurations
};

code usb_conf_desc_bootloader_t g_usb_conf_desc = 
{
    {
        sizeof(usb_conf_desc_t),
        USB_DESC_CONFIGURATION,
        SWAP(sizeof(usb_conf_desc_bootloader_t)),
        1,            // bNumInterfaces
        1,            // bConfigurationValue
        2,            // iConfiguration
        0xE0,         // bmAttributes - D6: self-powered, bus powered: 0xA0
        50,           // bMaxPower
    },
    /* Interface Descriptor 0 */ 
    {
        sizeof(usb_if_desc_t),
        USB_DESC_INTERFACE,
        0,            // bInterfaceNumber
        0,            // bAlternateSetting
        2,            // bNumEndpoints
        0xff,         // bInterfaceClass
        0x00,         // bInterfaceSubClass  
        0xff,         // bInterfaceProtocol 
        0x00,         // iInterface
    },
     /* Endpoint Descriptor EP1IN */
     {
        sizeof(usb_ep_desc_t),
        USB_DESC_ENDPOINT,
        0x81,                   // bEndpointAddress
        USB_ENDPOINT_TYPE_BULK, // bmAttributes
        SWAP(USB_EP1_SIZE),     // wMaxPacketSize
        0x06                    // bInterval
     },
     /* Endpoint Descriptor EP1OUT */
     {
        sizeof(usb_ep_desc_t),
        USB_DESC_ENDPOINT,
        0x01,                   // bEndpointAddress
        USB_ENDPOINT_TYPE_BULK, // bmAttributes
        SWAP(USB_EP1_SIZE),     // wMaxPacketSize
        0x06                    // bInterval
    },
};

#define USB_STRING_IDX_1_DESC "Promethos"

code uint8_t g_usb_string_desc_1[] = 
{
    sizeof(USB_STRING_IDX_1_DESC) * 2, 0x03,
    'P', 00,
    'r', 00,
    'o', 00,
    'm', 00,
    'e', 00,
    't', 00,
    'h', 00,
    'o', 00,
    's', 00
};

#define USB_STRING_IDX_2_DESC "Data Receiver 1.0"
code uint8_t g_usb_string_desc_2[] = 
{
    sizeof(USB_STRING_IDX_2_DESC) * 2, 0x03,
    'D', 00,
    'a', 00,
    't', 00,
    'a', 00,
    ' ', 00,
    'r', 00,
    'e', 00,
    'c', 00,
    'e', 00,
    'i', 00,
    'v', 00,
    'e', 00,
    'r', 00,
    ' ', 00,
    '1', 00,
    '.', 00,
    '0', 00
};

// USB_STRING_IDX_EE_DESC "Windows OS Descriptor request"
code uint8_t g_usb_string_desc_EE[] = 
{
    0x12, 0x03,			// 0x12 e' la dimensione della stringa di 18 byte, 0x03 e' il codice che indica che e' una stringa. Poi ci sono i caratteri in unicode UTF-16
    'M', 00,
    'S', 00,
    'F', 00,
    'T', 00,
    '1', 00,
    '0', 00,
    '0', 00,
	0xff,		// MS Vendor Code
	0x00		// Pad, must be 0x00
};

code uint8_t g_usb_extended_compat_id[] =
{
	0x28, 0x00, 0x00, 0x00,		// DWORD descriptor legnth (40 byte)
	0x00, 0x01,								// BCD WORD (LE) Version ('1.0') 
	0x04, 0x00,								// WORD (LE) Compatibility ID Descriptor index (0x0004) 
	0x01,											// BYTE Number of sections (1)
	0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00,					// 7 BYTES Reserved
	0x00,											// BYTE Interface Number (Interface #0) 
	0x01,											// BYTE Reserved 
	0x57, 0x49, 0x4E, 0x55,
	0x53, 0x42, 0x00, 0x00,		// 8 BYTES (NUL-terminated?) ASCII String Compatible ID ("WINUSB\0\0") 
	0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00,		// 8 BYTES (NUL-terminated?) ASCII String Sub-Compatible ID (unused)
	0x00, 0x00, 0x00, 0x00,		
	0x00, 0x00								// 6 BYTES Reserved
};


code uint8_t g_usb_extended_proper_os[] =
{
	0x8e, 0x00, 0x00, 0x00,		//dwLength
	0x00, 0x01,								//bcdVersion
	0x05, 0x00, 							//wIndex
	0x01, 0x00, 							//wCount
	//Property #1
	0x84, 0x00, 0x00, 0x00,		//dwSize
	0x01, 0x00, 0x00, 0x00,		//dwPropertyDataType
	0x28, 0x00,								//wPropertyNameLength
	'D',0, 'e',0, 'v',0, 			//bPropertyName The property name (DeviceInterfaceGUID)
	'i',0, 'c',0, 'e',0,
	'I',0, 'n',0, 't',0,
	'e',0, 'r',0, 'f',0,
	'a',0, 'c',0, 'e',0,
	'G',0, 'U',0, 'I',0,
	'D',0, 0, 0,	
	0x4e, 0x00, 0x00, 0x00,		//dwPropertyDataLength
	'{',0, '9',0, 'c',0,			//bPropertyData PDL Format-dependent Property data ({EA0BD5C3-50F3-4888-84B4-74E50E1649DB})
	'b',0, 'b',0, '6',0,
	'f',0, '9',0, 'f',0,
	'-',0, 'c',0, '1',0,
	'7',0, '9',0, '-',0,
	'4',0, 'a',0, 'c',0,
	'b',0, '-',0, '8',0,
	'1',0, 'c',0, '0',0,
	'-',0, 'b',0, '4',0, 
	'9',0, '1',0, '2',0, 
	'f',0, '4',0, '5',0, 
	'5',0, '7',0, '7',0, 
	'8',0, '}',0, 0, 0
	/*
	//Property #2
	0x3E, 0x00, 0x00, 0x00,	//dwSize
	0x01, 0x00, 0x00, 0x00,	//dwPropertyDataType
	0x0C, 0x00,							//wPropertyNameLength
	'L',0, 'a',0, 'b',0,		//bPropertyName
	'e',0, 'l',0, 0, 0,
	0x24, 0x00, 0x00, 0x00,	//dwPropertyDataLength
	'W',0, 'i',0, 'n',0,		//bPropertyData PDL Format-dependent Property data (WinUSBComm Device)
	'U',0, 'S',0, 'B',0,		
	'C',0, 'o',0, 'm',0, 
	'm',0, ' ',0, 'd',0, 
	'e',0, 'v',0, 'i',0, 
	'c',0, 'e',0, 0, 0*/
};

// This is for setting language American English (String descriptor 0 is an array of supported languages):
code uint8_t string_zero[] = {0x04, 0x03, 0x09, 0x04} ;
